class MeasureSoftGramCLIException(Exception):
    """Base MeasureSoftGram CLI Exception"""

    pass


class InvalidMetricException(MeasureSoftGramCLIException):
    """Raised when an invalid metric value is provided"""

    pass


class InvalidSonarFileAttributeException(MeasureSoftGramCLIException):
    """Raised when an sonar file attribute is incorrect"""

    pass


class InvalidBaseComponentException(MeasureSoftGramCLIException):
    """Raised when the field baseComponent from sonar metrics file is incorrect"""

    pass


class InvalidFileTypeException(MeasureSoftGramCLIException):
    """' Raised when the file type is not JSON"""

    pass


class MeasureSoftGramCliException(Exception):
    """Base MeasureSoftGram Cli exception"""

    pass


class FileNotFound(MeasureSoftGramCliException):
    """Raised when a invalid file path is provided to the MeasureSoftGram"""

    pass


class NullMetricValue(MeasureSoftGramCliException):
    """Raised when a NULL metric value is provided to the MeasureSoftGram"""

    pass



from src.cli.create import (
    validate_weight_sum,
    validate_weight_value,
    validate_check_box_input,
    define_weight,
    define_characteristic,
    define_subcharacteristics,
    define_measures,
    sublevel_cli,
)


def test_validate_weight_value():
    """
    Test for validate_weight_value function
    """
    assert validate_weight_value(0) is False
    assert validate_weight_value(50)
    assert validate_weight_value(100)
    assert validate_weight_value(-30) is False
    assert validate_weight_value(120) is False


def test_validate_weight_sum():
    """
    Test for validate_weight_value function
    """

    assert validate_weight_sum([{"reliability": "50"}, {"testability": "10"}]) is False
    assert validate_weight_sum(
        [{"maintanability": "20"}, {"reliability": "70"}, {"testability": "10"}]
    )
    assert (
        validate_weight_sum([{"maintanability": "70"}, {"testability": "40"}]) is False
    )
    assert validate_weight_sum([]) is False


def test_validate_check_box_input():
    """
    Test for validate_check_box_input function
    """
    assert validate_check_box_input(0) is False
    assert validate_check_box_input(3)


def test_define_weight(mocker):
    """
    Test for define_weight function
    """
    mocker.patch("inquirer.prompt", return_value={"usability": "50"})

    assert define_weight("usability", "Usability") == {"usability": "50"}


def test_sublevel_cli(mocker):
    """
    Test for sublevel_cli function
    """
    mocker.patch(
        "inquirer.prompt",
        return_value={
            "sublevels": [
                "Non Complex File Density",
                "Commented File Density",
            ],
        },
    )

    available_conf = {
        "non_complex_file_density": {
            "name": "Non Complex File Density",
        },
        "commented_file_density": {
            "name": "Commented File Density",
        },
        "duplication": {
            "name": "Duplication",
        },
    }

    assert sublevel_cli(
        "Modifiability",
        "measures",
        ["non_complex_file_density", "commented_file_density", "duplication"],
        available_conf,
    ) == ["non_complex_file_density", "commented_file_density"]


class TestDefineCharacteristics:
    def test_one_characteristic(self, mocker):
        """
        test for define_characteristics
        """
        mocker.patch("inquirer.prompt", return_value={"usability": "50"})

        available_conf = {"characteristics": {"usability": {"name": "Usability"}}}

        resp_user_characteristics, resp_characteristics_weights = define_characteristic(
            available_conf
        )

        assert len(resp_user_characteristics) == 1
        assert len(resp_characteristics_weights) == 1
        assert resp_user_characteristics == ["usability"]
        assert int(resp_characteristics_weights[0]["usability"]) == 100


class TestDefineSubCharacteristics:
    def test_one_sub_char(self):
        available_conf = {
            "subcharacteristics": {
                "testability": {
                    "name": "Testability",
                }
            }
        }

        u_characteristics = ["reliability"]

        resp_sub_chars, resp_sub_chars_weights = define_subcharacteristics(
            u_characteristics, available_conf
        )

        assert len(resp_sub_chars) == 1
        assert len(resp_sub_chars_weights) == 1
        assert resp_sub_chars == ["testability"]
        assert int(resp_sub_chars_weights[0]["testability"]) == 100


class TestDefineMeasures:
    def test_one_measure(self):
        available_conf = {
            "measures": {
                "non_complex_functions": {
                    "name": "Non Complex Functions",
                }
            }
        }

        u_sub_chars = ["testability"]

        resp_measures, resp_measures_weights = define_measures(
            u_sub_chars, available_conf
        )

        assert len(resp_measures) == 1
        assert len(resp_measures_weights) == 1
        assert resp_measures == ["non_complex_functions"]
        assert int(resp_measures_weights[0]["non_complex_functions"]) == 100



from src.cli.cliRunner import main
from io import StringIO


class DummyResponse:
    def json(self):
        return {
            "characteristics": {
                "usability": {
                    "name": "Usability",
                },
                "performance": {
                    "name": "Performance",
                },
            }
        }


def test_handle_sigint_in_create_form(mocker):
    """
    Test for KeyboardInterrupt exception handling
    """
    mocker.patch("requests.get", return_value=DummyResponse())
    mocker.patch("inquirer.prompt", side_effect=KeyboardInterrupt())
    mocker.patch("sys.argv", ["measuresoftgram", "create"])

    with mocker.patch("sys.stdout", new=StringIO()) as fake_out:

        main()

        assert "\nYou pressed Ctrl + C! No pre conf created." in fake_out.getvalue()



from src.cli import exceptions
import json


METRICS_SONAR = [
    "files",
    "functions",
    "complexity",
    "comment_lines_density",
    "duplicated_lines_density",
    "coverage",
    "ncloc",
    "tests",
    "test_errors",
    "test_failures",
    "test_execution_time",
    "security_rating",
]


def file_reader(absolute_path):

    check_file_extension(absolute_path)

    f = check_file_existance(absolute_path)
    json_file = json.load(f)
    check_sonar_format(json_file)

    components = json_file["components"]

    return components


def check_file_existance(absolute_path):

    try:
        file = open(absolute_path, "r")
    except FileNotFoundError:
        raise exceptions.FileNotFound("ERRO: arquivo não encontrado")

    return file


def check_sonar_format(json_file):
    attributes = list(json_file.keys())

    if len(attributes) != 3:
        raise exceptions.InvalidSonarFileAttributeException(
            "ERRO: Quantidade de atributos invalida"
        )
    if (
        attributes[0] != "paging"
        or attributes[1] != "baseComponent"
        or attributes[2] != "components"
    ):
        raise exceptions.InvalidSonarFileAttributeException(
            "ERRO: Atributos incorretos"
        )

    base_component = json_file["baseComponent"]
    base_component_attributs = list(base_component.keys())

    if len(base_component_attributs) != 5:
        raise exceptions.InvalidBaseComponentException(
            "ERRO: Quantidade de atributos de baseComponent invalida"
        )
    if (
        base_component_attributs[0] != "id"
        or base_component_attributs[1] != "key"
        or base_component_attributs[2] != "name"
        or base_component_attributs[3] != "qualifier"
        or base_component_attributs[4] != "measures"
    ):
        raise exceptions.InvalidBaseComponentException(
            "ERRO: Atributos de baseComponent incorretos"
        )

    return True


def check_file_extension(fileName):
    if fileName[-4:] != "json":
        raise exceptions.InvalidFileTypeException(
            "ERRO: Apenas arquivos JSON são aceitos"
        )
    return True


def validate_metrics_post(response_status, response):
    if response_status == 201:
        print("\nThe imported metrics were saved for the pre-configuration")
    else:
        print("\nThere was a ERROR while saving your Metrics:\n")

        for key, value in response.items():
            field_name = "General" if key == "__all__" else key

            print(f"\t{field_name} => {value}")



from src.cli import jsonReader, exceptions
import pytest
import json
from io import StringIO


def test_fileNotExist():
    """
    Testar se o arquivo existe na pasta
    """
    relativeFilePath = "tests/utils/sona.json"
    with pytest.raises(exceptions.FileNotFound):
        jsonReader.check_file_existance(relativeFilePath)


def test_ValidFileExtension():
    """
    Testa se a extensão do arquivo é válida (ex: .json)
    """

    file_name = "sonar.json"

    assert jsonReader.check_file_extension(file_name) is True


def test_notValidFileExtension():
    """
    Testa se a extensão do arquivo não é válida (ex: .txt, .png, .pdf)
    """

    file_name = "sonar.txt"

    with pytest.raises(exceptions.InvalidFileTypeException):
        jsonReader.check_file_extension(file_name)


def test_validSonarFormat():
    """
    Testa se um objeto json fornecido tem a formatação do Sonar
    """

    filePath = "tests/unit/data/sonar.json"
    f = open(filePath, "r")
    jsonFile = json.load(f)

    assert jsonReader.check_sonar_format(jsonFile) is True


def test_ifThereIsLessThanExpectedSonarAttributes():
    """
    Testa se um objeto json fornecido possui menos atributos
    do que o esperado
    """

    jsonFile = {
        "paging": {"pageIndex": 1, "pageSize": 100, "total": 5},
        "baseComponent": {
            "id": "AX9FgyLHNIj_v_uQK41e",
            "key": "fga-eps-mds_2021-2-MeasureSoftGram-CLI",
            "name": "2021-2-MeasureSoftGram-CLI",
            "qualifier": "TRK",
            "measures": [
                {
                    "metric": "duplicated_lines_density",
                    "value": "0.0",
                    "bestValue": True,
                }
            ],
        },
    }

    with pytest.raises(exceptions.InvalidSonarFileAttributeException) as exec_info:
        jsonReader.check_sonar_format(jsonFile) is True

    assert exec_info.value.args[0] == "ERRO: Quantidade de atributos invalida"


def test_ifThereIsMoreThanExpectedSonarAttributes():
    """
    Testa se um objeto json fornecido possui mais atributos
    do que o esperado
    """

    jsonFile = {
        "paging": {"pageIndex": 1, "pageSize": 100, "total": 5},
        "baseComponent": {
            "id": "AX9FgyLHNIj_v_uQK41e",
            "key": "fga-eps-mds_2021-2-MeasureSoftGram-CLI",
            "name": "2021-2-MeasureSoftGram-CLI",
            "qualifier": "TRK",
            "measures": [
                {
                    "metric": "duplicated_lines_density",
                    "value": "0.0",
                    "bestValue": True,
                }
            ],
        },
        "components": [
            {
                "id": "AX9GDsKlZuVL7NjXSAZ4",
                "key": "fga-eps-mds_2021-2-MeasureSoftGram-CLI:tests/__init__.py",
                "name": "__init__.py",
                "qualifier": "UTS",
                "path": "tests/__init__.py",
                "language": "py",
                "measures": [
                    {"metric": "security_rating", "value": "1.0", "bestValue": True}
                ],
            }
        ],
        "someOtherAttribute": {"hello": "world", "value": None},
    }

    with pytest.raises(exceptions.InvalidSonarFileAttributeException) as exec_info:
        jsonReader.check_sonar_format(jsonFile)

    assert exec_info.value.args[0] == "ERRO: Quantidade de atributos invalida"


def test_expectedJsonMainAtributes():
    """
    Testa se o json recebido possui um atributo diferente dos 3 esperados:
    paging, baseComponets ou Components
    """

    jsonFile = {
        "paging": {"pageIndex": 1, "pageSize": 100, "total": 5},
        "base": {
            "id": "AX9FgyLHNIj_v_uQK41e",
            "key": "fga-eps-mds_2021-2-MeasureSoftGram-CLI",
            "name": "2021-2-MeasureSoftGram-CLI",
            "qualifier": "TRK",
            "measures": [
                {
                    "metric": "duplicated_lines_density",
                    "value": "0.0",
                    "bestValue": True,
                }
            ],
        },
        "components": [
            {
                "id": "AX9GDsKlZuVL7NjXSAZ4",
                "key": "fga-eps-mds_2021-2-MeasureSoftGram-CLI:tests/__init__.py",
                "name": "__init__.py",
                "qualifier": "UTS",
                "path": "tests/__init__.py",
                "language": "py",
                "measures": [
                    {"metric": "security_rating", "value": "1.0", "bestValue": True}
                ],
            }
        ],
    }

    with pytest.raises(exceptions.InvalidSonarFileAttributeException) as exec_info:
        jsonReader.check_sonar_format(jsonFile)

    assert exec_info.value.args[0] == "ERRO: Atributos incorretos"


def test_validBaseComponentAttributs():
    """
    Testar se todos os atributos do baseComponent são validos
    """
    jsonFile = {
        "baseComponent": {
            "id": "AX9FgyLHNIj_v_uQK41e",
            "key": "fga-eps-mds_2021-2-MeasureSoftGram-CLI",
            "name": "2021-2-MeasureSoftGram-CLI",
            "qualifier": "TRK",
            "measures": [
                {
                    "metric": "duplicated_lines_density",
                    "value": "0.0",
                    "bestValue": True,
                }
            ],
        }
    }

    with pytest.raises(exceptions.InvalidSonarFileAttributeException):
        jsonReader.check_sonar_format(jsonFile) is True


def test_notValidBaseComponentAttributs():
    """
    Testar se algum dos atributos do baseComponent não é valido
    """
    jsonFile = {
        "baseComponent": {
            "id": "AX9FgyLHNIj_v_uQK41e",
            "keys": "fga-eps-mds_2021-2-MeasureSoftGram-CLI",
            "name": "2021-2-MeasureSoftGram-CLI",
            "qualifier": "TRK",
            "measures": [
                {
                    "metric": "duplicated_lines_density",
                    "value": "0.0",
                    "bestValue": True,
                }
            ],
        }
    }

    with pytest.raises(exceptions.InvalidSonarFileAttributeException):
        jsonReader.check_sonar_format(jsonFile)

    assert "ERRO: Atributo de baseComponet invalido."


def test_validate_metrics_post_success(mocker):
    """
    Test for validate_metrics_post_post function
    """

    with mocker.patch("sys.stdout", new=StringIO()) as fake_out:
        jsonReader.validate_metrics_post(response_status=201, response={})

        assert (
            "The imported metrics were saved for the pre-configuration"
            in fake_out.getvalue()
        )


def test_validate_metrics_post_error(mocker):
    """
    Test for validate_metrics_post_post function
    """

    with mocker.patch("sys.stdout", new=StringIO()) as fake_out:
        response = {
            "pre_config_id": "There is no pre configurations with ID 624b45ebac582da342adffc3"
        }

        jsonReader.validate_metrics_post(response_status=404, response=response)

        assert (
            "pre_config_id => There is no pre configurations with ID 624b45ebac582da342adffc3"
            in fake_out.getvalue()
        )



import argparse
import json
import sys
import requests
import signal
from pathlib import Path
from random import randrange
from src.cli.jsonReader import file_reader, validate_metrics_post
from src.cli.create import (
    define_characteristic,
    define_subcharacteristics,
    define_measures,
    validate_preconfig_post,
)

BASE_URL = "http://localhost:5000/"


def sigint_handler(*_):
    print("\n\nExiting MeasureSoftGram...")
    sys.exit(0)


def parse_import(file_path, id):
    components = file_reader(r"{}".format(file_path))

    payload = {"pre_config_id": id, "components": components}

    response = requests.post(BASE_URL + "import-metrics", json=payload)

    validate_metrics_post(response.status_code, json.loads(response.text))


def parse_create():
    print("Creating a new pre conf")

    available_pre_config = requests.get(
        BASE_URL + "available-pre-configs", headers={"Accept": "application/json"}
    ).json()

    [user_characteristics, caracteristics_weights] = define_characteristic(
        available_pre_config
    )

    [user_sub_characteristic, sub_characteristic_weights] = define_subcharacteristics(
        user_characteristics, available_pre_config
    )

    [user_measures, measures_weights] = define_measures(
        user_sub_characteristic, available_pre_config
    )

    pre_config_name = f"msg_pre_config_{randrange(5)}"

    data = {
        "name": pre_config_name,
        "characteristics": user_characteristics,
        "subcharacteristics": user_sub_characteristic,
        "measures": user_measures,
        "characteristics_weights": caracteristics_weights,
        "subcharacteristics_weights": sub_characteristic_weights,
        "measures_weights": measures_weights,
    }

    response = requests.post(BASE_URL + "/pre-configs", json=data)

    saved_preconfig = json.loads(response.text)

    validate_preconfig_post(response.status_code, saved_preconfig)


def setup():
    parser = argparse.ArgumentParser(
        description="Command line interface for measuresoftgram"
    )
    subparsers = parser.add_subparsers(dest="command", help="sub-command help")

    parser_import = subparsers.add_parser("import", help="Import a metrics file")

    parser_import.add_argument(
        "path",
        type=lambda p: Path(p).absolute(),
        default=Path(__file__).absolute().parent / "data",
        help="Path to the data directory",
    )

    parser_import.add_argument(
        "id",
        type=str,
        help="Pre config ID",
    )

    subparsers.add_parser("create", help="Create a new model pre configuration")

    args = parser.parse_args()

    # if args is empty show help
    if not sys.argv[1:]:
        parser.print_help()
        return
    elif args.command == "import":
        parse_import(args.path, args.id)
    elif args.command == "create":
        parse_create()


def main():
    """Entry point for the application script"""

    signal.signal(signal.SIGINT, sigint_handler)

    try:
        setup()
    except KeyboardInterrupt:
        print("\nYou pressed Ctrl + C! No pre conf created.")



import inquirer
from inquirer.themes import GreenPassion

VALID_WEIGHT_SUM_ADVISE = "the sum of the weights must be 100"
INVALID_WEIGHT_SUM_ERROR = "Invalid weights," + VALID_WEIGHT_SUM_ADVISE

VALID_WEIGHT_ADVISE = "the weight must be between 0 and 100"
INVALID_WEIGHT_VALUE = "Invalid weight, " + VALID_WEIGHT_ADVISE

VALID_CHECKBOX_ERROR = "Select at least one Check-Box"


def define_weight(data_key, data_name):
    while True:
        weights = [
            inquirer.Text(
                data_key,
                message="Enter the weight of "
                + data_name
                + f" ({VALID_WEIGHT_SUM_ADVISE})",
            )
        ]
        defined_weight = inquirer.prompt(
            weights, theme=GreenPassion(), raise_keyboard_interrupt=True
        )
        if validate_weight_value(int(defined_weight[data_key])):
            break
        print(INVALID_WEIGHT_VALUE)

    return defined_weight


def validate_weight_sum(items):
    sum = 0
    for x in items:
        for k, v in x.items():
            sum += int(v)

    if sum != 100:
        return False
    else:
        return True


def validate_weight_value(weight):
    if weight > 100 or weight <= 0:
        return False
    else:
        return True


def validate_check_box_input(selected):
    if selected > 0:
        return True
    else:
        return False


def validate_preconfig_post(status_code, response):
    if status_code == 201:
        print(
            f"\nYour Pre Configuration was created with sucess!\nPre Configuration ID: {response['_id']}"
        )
    else:
        print(
            f"\nThere was an ERROR while creating your Pre Configuration:  {response['error']}"
        )


def sublevel_cli(level_name, level_alias, sublevels, available_pre_config):
    reverse_sublevel = {v["name"]: k for k, v in available_pre_config.items()}

    sublevels_answer = [
        inquirer.Checkbox(
            "sublevels",
            message="Choose the " + level_alias + " for " + level_name,
            choices=[available_pre_config[x]["name"] for x in sublevels],
        )
    ]
    user_sublevels = inquirer.prompt(
        sublevels_answer, theme=GreenPassion(), raise_keyboard_interrupt=True
    )

    user_sublevels = [reverse_sublevel[x] for x in user_sublevels["sublevels"]]

    return user_sublevels


def define_characteristic(available_pre_config):
    characteristics = available_pre_config["characteristics"]

    if len(characteristics) == 1:
        user_characteristics = list(characteristics.keys())
        characteristics_weights = [{user_characteristics[0]: 100}]
        return user_characteristics, characteristics_weights

    reversed_characteristics = {v["name"]: k for k, v in characteristics.items()}
    while True:
        characteristics_answer = [
            inquirer.Checkbox(
                "characteristics",
                message="Choose the characteristics",
                choices=[x["name"] for _, x in characteristics.items()],
            )
        ]

        user_characteristics = inquirer.prompt(
            characteristics_answer, theme=GreenPassion(), raise_keyboard_interrupt=True
        )

        if validate_check_box_input(len(user_characteristics["characteristics"])):
            break
        else:
            print(VALID_CHECKBOX_ERROR)

    user_characteristics = [
        reversed_characteristics[x] for x in user_characteristics["characteristics"]
    ]

    if len(user_characteristics) == 1:
        print("\nOnly one characteristic selected, no need to define weights")
        characteristics_weights = [{user_characteristics[0]: 100}]
        return user_characteristics, characteristics_weights

    characteristics_weights = []

    while True:
        for x in user_characteristics:
            characteristics_weights.append(define_weight(x, characteristics[x]["name"]))

        if validate_weight_sum(characteristics_weights):
            break
        else:
            print(INVALID_WEIGHT_SUM_ERROR)
            characteristics_weights = []

    return user_characteristics, characteristics_weights


def define_measures(user_sub_characteristics, available_pre_config):
    measures = available_pre_config["measures"]

    if len(measures) == 1:
        user_measures = list(measures.keys())
        measures_weights = [{user_measures[0]: 100}]
        return user_measures, measures_weights

    selected_measures = []
    measures_weights = []

    for x in user_sub_characteristics:
        if len(available_pre_config["subcharacteristics"][x]["measures"]) == 1:
            local_selected_measures = available_pre_config["subcharacteristics"][x][
                "measures"
            ]
            local_measures_weights = [{local_selected_measures[0]: 100}]
            print(
                "\nOnly one measure (%s) available, no need to select or define weights\n"
                % (available_pre_config["measures"][local_selected_measures[0]]["name"])
            )

        else:
            while True:
                local_selected_measures = sublevel_cli(
                    available_pre_config["subcharacteristics"][x]["name"],
                    "measures",
                    available_pre_config["subcharacteristics"][x]["measures"],
                    available_pre_config["measures"],
                )

                if validate_check_box_input(len(local_selected_measures)):
                    break
                else:
                    print(VALID_CHECKBOX_ERROR)

        local_measures_weights = []

        while True:
            for y in local_selected_measures:
                local_measures_weights.append(
                    define_weight(y, available_pre_config["measures"][y]["name"])
                )

            if validate_weight_sum(local_measures_weights):
                break
            else:
                print(INVALID_WEIGHT_SUM_ERROR)
                local_measures_weights = []

        selected_measures.extend(local_selected_measures)
        measures_weights.extend(local_measures_weights)

    return selected_measures, measures_weights


def define_subcharacteristics(user_characteristics, available_pre_config):
    sub_characteristic = available_pre_config["subcharacteristics"]

    if len(sub_characteristic) == 1:
        user_sub_characteristics = list(sub_characteristic.keys())
        subcharacteristics_weights = [{user_sub_characteristics[0]: 100}]
        return user_sub_characteristics, subcharacteristics_weights

    selected_sub_characteristics = []
    sub_characteristic_weights = []
    for x in user_characteristics:
        if len(available_pre_config["characteristics"][x]["subcharacteristics"]) == 1:
            local_selected_sub_characteristics = available_pre_config[
                "characteristics"
            ][x]["subcharacteristics"]
            local_sub_characteristics_weights = [
                {local_selected_sub_characteristics[0]: 100}
            ]
            print(
                "\nOnly one subcharacteristic (%s) available, no need to select or define weights\n"
                % (
                    available_pre_config["subcharacteristics"][
                        local_selected_sub_characteristics[0]
                    ]["name"]
                )
            )
        else:
            local_selected_sub_characteristics = sublevel_cli(
                available_pre_config["characteristics"][x]["name"],
                "subcharacteristics",
                available_pre_config["characteristics"][x]["subcharacteristics"],
                available_pre_config["subcharacteristics"],
            )

            local_sub_characteristics_weights = []

            while True:
                for y in local_selected_sub_characteristics:
                    local_sub_characteristics_weights.append(
                        define_weight(
                            y, available_pre_config["subcharacteristics"][y]["name"]
                        )
                    )

                if validate_weight_sum(local_sub_characteristics_weights):
                    break
                else:
                    print(INVALID_WEIGHT_SUM_ERROR)
                    local_sub_characteristics_weights = []

        selected_sub_characteristics.extend(local_selected_sub_characteristics)
        sub_characteristic_weights.extend(local_sub_characteristics_weights)

    return selected_sub_characteristics, sub_characteristic_weights



from setuptools import setup, find_packages

setup(
    name="measuresoftgram",
    version="1.1.0",
    extras_require={"dev": ["pytest", "pytest-cov", "setuptools", "wheel"]},
    packages=find_packages(),
    install_requires=["inquirer==2.8.0", "requests"],
    # To provide executable scripts, use entry points in preference to the
    # "scripts" keyword. Entry points provide cross-platform support and allow
    # pip to create the appropriate form of executable for the target platform.
    entry_points={"console_scripts": ["measuresoftgram=src.cli.cliRunner:main"]},
)



import json
import requests
import sys
from datetime import datetime

TODAY = datetime.now()

METRICS_SONAR = [
    "files",
    "functions",
    "complexity",
    "comment_lines_density",
    "duplicated_lines_density",
    "coverage",
    "ncloc",
    "tests",
    "test_errors",
    "test_failures",
    "test_execution_time",
    "security_rating",
]

BASE_URL = "https://sonarcloud.io/api/measures/component_tree?component=fga-eps-mds_"

if __name__ == "__main__":

    REPO = sys.argv[1]
    RELEASE_VERSION = sys.argv[2]

    response = requests.get(
        f'{BASE_URL}{REPO}&metricKeys={",".join(METRICS_SONAR)}&ps=500'
    )
    j = json.loads(response.text)

    file_path = f'./analytics-raw-data/fga-eps-mds-{REPO}-{TODAY.strftime("%m-%d-%Y-%H-%M-%S")}-{RELEASE_VERSION}.json'

    with open(file_path, "w") as fp:
        fp.write(json.dumps(j))
        fp.close()
